# This file is generated by make.paws. Please do not edit here.
#' @importFrom paws.common get_config new_operation new_request send_request
#' @include connectwisdomservice_service.R
NULL

#' Creates an Amazon Connect Wisdom assistant
#'
#' @description
#' Creates an Amazon Connect Wisdom assistant.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/create_assistant.html](https://paws-r.github.io/docs/connectwisdomservice/create_assistant.html) for full documentation.
#'
#' @param clientToken A unique, case-sensitive identifier that you provide to ensure the
#' idempotency of the request.
#' @param description The description of the assistant.
#' @param name &#91;required&#93; The name of the assistant.
#' @param serverSideEncryptionConfiguration The KMS key used for encryption.
#' @param tags The tags used to organize, track, or control access for this resource.
#' @param type &#91;required&#93; The type of assistant.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_create_assistant
connectwisdomservice_create_assistant <- function(clientToken = NULL, description = NULL, name, serverSideEncryptionConfiguration = NULL, tags = NULL, type) {
  op <- new_operation(
    name = "CreateAssistant",
    http_method = "POST",
    http_path = "/assistants",
    paginator = list()
  )
  input <- .connectwisdomservice$create_assistant_input(clientToken = clientToken, description = description, name = name, serverSideEncryptionConfiguration = serverSideEncryptionConfiguration, tags = tags, type = type)
  output <- .connectwisdomservice$create_assistant_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$create_assistant <- connectwisdomservice_create_assistant

#' Creates an association between an Amazon Connect Wisdom assistant and
#' another resource
#'
#' @description
#' Creates an association between an Amazon Connect Wisdom assistant and another resource. Currently, the only supported association is with a knowledge base. An assistant can have only a single association.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/create_assistant_association.html](https://paws-r.github.io/docs/connectwisdomservice/create_assistant_association.html) for full documentation.
#'
#' @param assistantId &#91;required&#93; The identifier of the Wisdom assistant. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#' @param association &#91;required&#93; The identifier of the associated resource.
#' @param associationType &#91;required&#93; The type of association.
#' @param clientToken A unique, case-sensitive identifier that you provide to ensure the
#' idempotency of the request.
#' @param tags The tags used to organize, track, or control access for this resource.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_create_assistant_association
connectwisdomservice_create_assistant_association <- function(assistantId, association, associationType, clientToken = NULL, tags = NULL) {
  op <- new_operation(
    name = "CreateAssistantAssociation",
    http_method = "POST",
    http_path = "/assistants/{assistantId}/associations",
    paginator = list()
  )
  input <- .connectwisdomservice$create_assistant_association_input(assistantId = assistantId, association = association, associationType = associationType, clientToken = clientToken, tags = tags)
  output <- .connectwisdomservice$create_assistant_association_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$create_assistant_association <- connectwisdomservice_create_assistant_association

#' Creates Wisdom content
#'
#' @description
#' Creates Wisdom content. Before to calling this API, use [`start_content_upload`][connectwisdomservice_start_content_upload] to upload an asset.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/create_content.html](https://paws-r.github.io/docs/connectwisdomservice/create_content.html) for full documentation.
#'
#' @param clientToken A unique, case-sensitive identifier that you provide to ensure the
#' idempotency of the request.
#' @param knowledgeBaseId &#91;required&#93; The identifier of the knowledge base. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#' @param metadata A key/value map to store attributes without affecting tagging or
#' recommendations. For example, when synchronizing data between an
#' external system and Wisdom, you can store an external version identifier
#' as metadata to utilize for determining drift.
#' @param name &#91;required&#93; The name of the content. Each piece of content in a knowledge base must
#' have a unique name. You can retrieve a piece of content using only its
#' knowledge base and its name with the
#' [`search_content`][connectwisdomservice_search_content] API.
#' @param overrideLinkOutUri The URI you want to use for the article. If the knowledge base has a
#' templateUri, setting this argument overrides it for this piece of
#' content.
#' @param tags The tags used to organize, track, or control access for this resource.
#' @param title The title of the content. If not set, the title is equal to the name.
#' @param uploadId &#91;required&#93; A pointer to the uploaded asset. This value is returned by
#' [`start_content_upload`][connectwisdomservice_start_content_upload].
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_create_content
connectwisdomservice_create_content <- function(clientToken = NULL, knowledgeBaseId, metadata = NULL, name, overrideLinkOutUri = NULL, tags = NULL, title = NULL, uploadId) {
  op <- new_operation(
    name = "CreateContent",
    http_method = "POST",
    http_path = "/knowledgeBases/{knowledgeBaseId}/contents",
    paginator = list()
  )
  input <- .connectwisdomservice$create_content_input(clientToken = clientToken, knowledgeBaseId = knowledgeBaseId, metadata = metadata, name = name, overrideLinkOutUri = overrideLinkOutUri, tags = tags, title = title, uploadId = uploadId)
  output <- .connectwisdomservice$create_content_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$create_content <- connectwisdomservice_create_content

#' Creates a knowledge base
#'
#' @description
#' Creates a knowledge base.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/create_knowledge_base.html](https://paws-r.github.io/docs/connectwisdomservice/create_knowledge_base.html) for full documentation.
#'
#' @param clientToken A unique, case-sensitive identifier that you provide to ensure the
#' idempotency of the request.
#' @param description The description.
#' @param knowledgeBaseType &#91;required&#93; The type of knowledge base. Only CUSTOM knowledge bases allow you to
#' upload your own content. EXTERNAL knowledge bases support integrations
#' with third-party systems whose content is synchronized automatically.
#' @param name &#91;required&#93; The name of the knowledge base.
#' @param renderingConfiguration Information about how to render the content.
#' @param serverSideEncryptionConfiguration The KMS key used for encryption.
#' @param sourceConfiguration The source of the knowledge base content. Only set this argument for
#' EXTERNAL knowledge bases.
#' @param tags The tags used to organize, track, or control access for this resource.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_create_knowledge_base
connectwisdomservice_create_knowledge_base <- function(clientToken = NULL, description = NULL, knowledgeBaseType, name, renderingConfiguration = NULL, serverSideEncryptionConfiguration = NULL, sourceConfiguration = NULL, tags = NULL) {
  op <- new_operation(
    name = "CreateKnowledgeBase",
    http_method = "POST",
    http_path = "/knowledgeBases",
    paginator = list()
  )
  input <- .connectwisdomservice$create_knowledge_base_input(clientToken = clientToken, description = description, knowledgeBaseType = knowledgeBaseType, name = name, renderingConfiguration = renderingConfiguration, serverSideEncryptionConfiguration = serverSideEncryptionConfiguration, sourceConfiguration = sourceConfiguration, tags = tags)
  output <- .connectwisdomservice$create_knowledge_base_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$create_knowledge_base <- connectwisdomservice_create_knowledge_base

#' Creates a session
#'
#' @description
#' Creates a session. A session is a contextual container used for generating recommendations. Amazon Connect creates a new Wisdom session for each contact on which Wisdom is enabled.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/create_session.html](https://paws-r.github.io/docs/connectwisdomservice/create_session.html) for full documentation.
#'
#' @param assistantId &#91;required&#93; The identifier of the Wisdom assistant. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#' @param clientToken A unique, case-sensitive identifier that you provide to ensure the
#' idempotency of the request.
#' @param description The description.
#' @param name &#91;required&#93; The name of the session.
#' @param tags The tags used to organize, track, or control access for this resource.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_create_session
connectwisdomservice_create_session <- function(assistantId, clientToken = NULL, description = NULL, name, tags = NULL) {
  op <- new_operation(
    name = "CreateSession",
    http_method = "POST",
    http_path = "/assistants/{assistantId}/sessions",
    paginator = list()
  )
  input <- .connectwisdomservice$create_session_input(assistantId = assistantId, clientToken = clientToken, description = description, name = name, tags = tags)
  output <- .connectwisdomservice$create_session_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$create_session <- connectwisdomservice_create_session

#' Deletes an assistant
#'
#' @description
#' Deletes an assistant.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/delete_assistant.html](https://paws-r.github.io/docs/connectwisdomservice/delete_assistant.html) for full documentation.
#'
#' @param assistantId &#91;required&#93; The identifier of the Wisdom assistant. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_delete_assistant
connectwisdomservice_delete_assistant <- function(assistantId) {
  op <- new_operation(
    name = "DeleteAssistant",
    http_method = "DELETE",
    http_path = "/assistants/{assistantId}",
    paginator = list()
  )
  input <- .connectwisdomservice$delete_assistant_input(assistantId = assistantId)
  output <- .connectwisdomservice$delete_assistant_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$delete_assistant <- connectwisdomservice_delete_assistant

#' Deletes an assistant association
#'
#' @description
#' Deletes an assistant association.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/delete_assistant_association.html](https://paws-r.github.io/docs/connectwisdomservice/delete_assistant_association.html) for full documentation.
#'
#' @param assistantAssociationId &#91;required&#93; The identifier of the assistant association. Can be either the ID or the
#' ARN. URLs cannot contain the ARN.
#' @param assistantId &#91;required&#93; The identifier of the Wisdom assistant. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_delete_assistant_association
connectwisdomservice_delete_assistant_association <- function(assistantAssociationId, assistantId) {
  op <- new_operation(
    name = "DeleteAssistantAssociation",
    http_method = "DELETE",
    http_path = "/assistants/{assistantId}/associations/{assistantAssociationId}",
    paginator = list()
  )
  input <- .connectwisdomservice$delete_assistant_association_input(assistantAssociationId = assistantAssociationId, assistantId = assistantId)
  output <- .connectwisdomservice$delete_assistant_association_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$delete_assistant_association <- connectwisdomservice_delete_assistant_association

#' Deletes the content
#'
#' @description
#' Deletes the content.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/delete_content.html](https://paws-r.github.io/docs/connectwisdomservice/delete_content.html) for full documentation.
#'
#' @param contentId &#91;required&#93; The identifier of the content. Can be either the ID or the ARN. URLs
#' cannot contain the ARN.
#' @param knowledgeBaseId &#91;required&#93; The identifier of the knowledge base. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_delete_content
connectwisdomservice_delete_content <- function(contentId, knowledgeBaseId) {
  op <- new_operation(
    name = "DeleteContent",
    http_method = "DELETE",
    http_path = "/knowledgeBases/{knowledgeBaseId}/contents/{contentId}",
    paginator = list()
  )
  input <- .connectwisdomservice$delete_content_input(contentId = contentId, knowledgeBaseId = knowledgeBaseId)
  output <- .connectwisdomservice$delete_content_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$delete_content <- connectwisdomservice_delete_content

#' Deletes the knowledge base
#'
#' @description
#' Deletes the knowledge base.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/delete_knowledge_base.html](https://paws-r.github.io/docs/connectwisdomservice/delete_knowledge_base.html) for full documentation.
#'
#' @param knowledgeBaseId &#91;required&#93; The knowledge base to delete content from. Can be either the ID or the
#' ARN. URLs cannot contain the ARN.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_delete_knowledge_base
connectwisdomservice_delete_knowledge_base <- function(knowledgeBaseId) {
  op <- new_operation(
    name = "DeleteKnowledgeBase",
    http_method = "DELETE",
    http_path = "/knowledgeBases/{knowledgeBaseId}",
    paginator = list()
  )
  input <- .connectwisdomservice$delete_knowledge_base_input(knowledgeBaseId = knowledgeBaseId)
  output <- .connectwisdomservice$delete_knowledge_base_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$delete_knowledge_base <- connectwisdomservice_delete_knowledge_base

#' Retrieves information about an assistant
#'
#' @description
#' Retrieves information about an assistant.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/get_assistant.html](https://paws-r.github.io/docs/connectwisdomservice/get_assistant.html) for full documentation.
#'
#' @param assistantId &#91;required&#93; The identifier of the Wisdom assistant. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_get_assistant
connectwisdomservice_get_assistant <- function(assistantId) {
  op <- new_operation(
    name = "GetAssistant",
    http_method = "GET",
    http_path = "/assistants/{assistantId}",
    paginator = list()
  )
  input <- .connectwisdomservice$get_assistant_input(assistantId = assistantId)
  output <- .connectwisdomservice$get_assistant_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$get_assistant <- connectwisdomservice_get_assistant

#' Retrieves information about an assistant association
#'
#' @description
#' Retrieves information about an assistant association.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/get_assistant_association.html](https://paws-r.github.io/docs/connectwisdomservice/get_assistant_association.html) for full documentation.
#'
#' @param assistantAssociationId &#91;required&#93; The identifier of the assistant association. Can be either the ID or the
#' ARN. URLs cannot contain the ARN.
#' @param assistantId &#91;required&#93; The identifier of the Wisdom assistant. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_get_assistant_association
connectwisdomservice_get_assistant_association <- function(assistantAssociationId, assistantId) {
  op <- new_operation(
    name = "GetAssistantAssociation",
    http_method = "GET",
    http_path = "/assistants/{assistantId}/associations/{assistantAssociationId}",
    paginator = list()
  )
  input <- .connectwisdomservice$get_assistant_association_input(assistantAssociationId = assistantAssociationId, assistantId = assistantId)
  output <- .connectwisdomservice$get_assistant_association_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$get_assistant_association <- connectwisdomservice_get_assistant_association

#' Retrieves content, including a pre-signed URL to download the content
#'
#' @description
#' Retrieves content, including a pre-signed URL to download the content.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/get_content.html](https://paws-r.github.io/docs/connectwisdomservice/get_content.html) for full documentation.
#'
#' @param contentId &#91;required&#93; The identifier of the content. Can be either the ID or the ARN. URLs
#' cannot contain the ARN.
#' @param knowledgeBaseId &#91;required&#93; The identifier of the knowledge base. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_get_content
connectwisdomservice_get_content <- function(contentId, knowledgeBaseId) {
  op <- new_operation(
    name = "GetContent",
    http_method = "GET",
    http_path = "/knowledgeBases/{knowledgeBaseId}/contents/{contentId}",
    paginator = list()
  )
  input <- .connectwisdomservice$get_content_input(contentId = contentId, knowledgeBaseId = knowledgeBaseId)
  output <- .connectwisdomservice$get_content_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$get_content <- connectwisdomservice_get_content

#' Retrieves summary information about the content
#'
#' @description
#' Retrieves summary information about the content.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/get_content_summary.html](https://paws-r.github.io/docs/connectwisdomservice/get_content_summary.html) for full documentation.
#'
#' @param contentId &#91;required&#93; The identifier of the content. Can be either the ID or the ARN. URLs
#' cannot contain the ARN.
#' @param knowledgeBaseId &#91;required&#93; The identifier of the knowledge base. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_get_content_summary
connectwisdomservice_get_content_summary <- function(contentId, knowledgeBaseId) {
  op <- new_operation(
    name = "GetContentSummary",
    http_method = "GET",
    http_path = "/knowledgeBases/{knowledgeBaseId}/contents/{contentId}/summary",
    paginator = list()
  )
  input <- .connectwisdomservice$get_content_summary_input(contentId = contentId, knowledgeBaseId = knowledgeBaseId)
  output <- .connectwisdomservice$get_content_summary_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$get_content_summary <- connectwisdomservice_get_content_summary

#' Retrieves information about the knowledge base
#'
#' @description
#' Retrieves information about the knowledge base.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/get_knowledge_base.html](https://paws-r.github.io/docs/connectwisdomservice/get_knowledge_base.html) for full documentation.
#'
#' @param knowledgeBaseId &#91;required&#93; The identifier of the knowledge base. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_get_knowledge_base
connectwisdomservice_get_knowledge_base <- function(knowledgeBaseId) {
  op <- new_operation(
    name = "GetKnowledgeBase",
    http_method = "GET",
    http_path = "/knowledgeBases/{knowledgeBaseId}",
    paginator = list()
  )
  input <- .connectwisdomservice$get_knowledge_base_input(knowledgeBaseId = knowledgeBaseId)
  output <- .connectwisdomservice$get_knowledge_base_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$get_knowledge_base <- connectwisdomservice_get_knowledge_base

#' Retrieves recommendations for the specified session
#'
#' @description
#' Retrieves recommendations for the specified session. To avoid retrieving the same recommendations in subsequent calls, use [`notify_recommendations_received`][connectwisdomservice_notify_recommendations_received]. This API supports long-polling behavior with the `waitTimeSeconds` parameter. Short poll is the default behavior and only returns recommendations already available. To perform a manual query against an assistant, use [`query_assistant`][connectwisdomservice_query_assistant].
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/get_recommendations.html](https://paws-r.github.io/docs/connectwisdomservice/get_recommendations.html) for full documentation.
#'
#' @param assistantId &#91;required&#93; The identifier of the Wisdom assistant. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#' @param maxResults The maximum number of results to return per page.
#' @param sessionId &#91;required&#93; The identifier of the session. Can be either the ID or the ARN. URLs
#' cannot contain the ARN.
#' @param waitTimeSeconds The duration (in seconds) for which the call waits for a recommendation
#' to be made available before returning. If a recommendation is available,
#' the call returns sooner than `WaitTimeSeconds`. If no messages are
#' available and the wait time expires, the call returns successfully with
#' an empty list.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_get_recommendations
connectwisdomservice_get_recommendations <- function(assistantId, maxResults = NULL, sessionId, waitTimeSeconds = NULL) {
  op <- new_operation(
    name = "GetRecommendations",
    http_method = "GET",
    http_path = "/assistants/{assistantId}/sessions/{sessionId}/recommendations",
    paginator = list()
  )
  input <- .connectwisdomservice$get_recommendations_input(assistantId = assistantId, maxResults = maxResults, sessionId = sessionId, waitTimeSeconds = waitTimeSeconds)
  output <- .connectwisdomservice$get_recommendations_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$get_recommendations <- connectwisdomservice_get_recommendations

#' Retrieves information for a specified session
#'
#' @description
#' Retrieves information for a specified session.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/get_session.html](https://paws-r.github.io/docs/connectwisdomservice/get_session.html) for full documentation.
#'
#' @param assistantId &#91;required&#93; The identifier of the Wisdom assistant. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#' @param sessionId &#91;required&#93; The identifier of the session. Can be either the ID or the ARN. URLs
#' cannot contain the ARN.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_get_session
connectwisdomservice_get_session <- function(assistantId, sessionId) {
  op <- new_operation(
    name = "GetSession",
    http_method = "GET",
    http_path = "/assistants/{assistantId}/sessions/{sessionId}",
    paginator = list()
  )
  input <- .connectwisdomservice$get_session_input(assistantId = assistantId, sessionId = sessionId)
  output <- .connectwisdomservice$get_session_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$get_session <- connectwisdomservice_get_session

#' Lists information about assistant associations
#'
#' @description
#' Lists information about assistant associations.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/list_assistant_associations.html](https://paws-r.github.io/docs/connectwisdomservice/list_assistant_associations.html) for full documentation.
#'
#' @param assistantId &#91;required&#93; The identifier of the Wisdom assistant. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#' @param maxResults The maximum number of results to return per page.
#' @param nextToken The token for the next set of results. Use the value returned in the
#' previous response in the next request to retrieve the next set of
#' results.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_list_assistant_associations
connectwisdomservice_list_assistant_associations <- function(assistantId, maxResults = NULL, nextToken = NULL) {
  op <- new_operation(
    name = "ListAssistantAssociations",
    http_method = "GET",
    http_path = "/assistants/{assistantId}/associations",
    paginator = list()
  )
  input <- .connectwisdomservice$list_assistant_associations_input(assistantId = assistantId, maxResults = maxResults, nextToken = nextToken)
  output <- .connectwisdomservice$list_assistant_associations_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$list_assistant_associations <- connectwisdomservice_list_assistant_associations

#' Lists information about assistants
#'
#' @description
#' Lists information about assistants.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/list_assistants.html](https://paws-r.github.io/docs/connectwisdomservice/list_assistants.html) for full documentation.
#'
#' @param maxResults The maximum number of results to return per page.
#' @param nextToken The token for the next set of results. Use the value returned in the
#' previous response in the next request to retrieve the next set of
#' results.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_list_assistants
connectwisdomservice_list_assistants <- function(maxResults = NULL, nextToken = NULL) {
  op <- new_operation(
    name = "ListAssistants",
    http_method = "GET",
    http_path = "/assistants",
    paginator = list()
  )
  input <- .connectwisdomservice$list_assistants_input(maxResults = maxResults, nextToken = nextToken)
  output <- .connectwisdomservice$list_assistants_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$list_assistants <- connectwisdomservice_list_assistants

#' Lists the content
#'
#' @description
#' Lists the content.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/list_contents.html](https://paws-r.github.io/docs/connectwisdomservice/list_contents.html) for full documentation.
#'
#' @param knowledgeBaseId &#91;required&#93; The identifier of the knowledge base. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#' @param maxResults The maximum number of results to return per page.
#' @param nextToken The token for the next set of results. Use the value returned in the
#' previous response in the next request to retrieve the next set of
#' results.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_list_contents
connectwisdomservice_list_contents <- function(knowledgeBaseId, maxResults = NULL, nextToken = NULL) {
  op <- new_operation(
    name = "ListContents",
    http_method = "GET",
    http_path = "/knowledgeBases/{knowledgeBaseId}/contents",
    paginator = list()
  )
  input <- .connectwisdomservice$list_contents_input(knowledgeBaseId = knowledgeBaseId, maxResults = maxResults, nextToken = nextToken)
  output <- .connectwisdomservice$list_contents_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$list_contents <- connectwisdomservice_list_contents

#' Lists the knowledge bases
#'
#' @description
#' Lists the knowledge bases.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/list_knowledge_bases.html](https://paws-r.github.io/docs/connectwisdomservice/list_knowledge_bases.html) for full documentation.
#'
#' @param maxResults The maximum number of results to return per page.
#' @param nextToken The token for the next set of results. Use the value returned in the
#' previous response in the next request to retrieve the next set of
#' results.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_list_knowledge_bases
connectwisdomservice_list_knowledge_bases <- function(maxResults = NULL, nextToken = NULL) {
  op <- new_operation(
    name = "ListKnowledgeBases",
    http_method = "GET",
    http_path = "/knowledgeBases",
    paginator = list()
  )
  input <- .connectwisdomservice$list_knowledge_bases_input(maxResults = maxResults, nextToken = nextToken)
  output <- .connectwisdomservice$list_knowledge_bases_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$list_knowledge_bases <- connectwisdomservice_list_knowledge_bases

#' Lists the tags for the specified resource
#'
#' @description
#' Lists the tags for the specified resource.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/list_tags_for_resource.html](https://paws-r.github.io/docs/connectwisdomservice/list_tags_for_resource.html) for full documentation.
#'
#' @param resourceArn &#91;required&#93; The Amazon Resource Name (ARN) of the resource.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_list_tags_for_resource
connectwisdomservice_list_tags_for_resource <- function(resourceArn) {
  op <- new_operation(
    name = "ListTagsForResource",
    http_method = "GET",
    http_path = "/tags/{resourceArn}",
    paginator = list()
  )
  input <- .connectwisdomservice$list_tags_for_resource_input(resourceArn = resourceArn)
  output <- .connectwisdomservice$list_tags_for_resource_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$list_tags_for_resource <- connectwisdomservice_list_tags_for_resource

#' Removes the specified recommendations from the specified assistant's
#' queue of newly available recommendations
#'
#' @description
#' Removes the specified recommendations from the specified assistant's queue of newly available recommendations. You can use this API in conjunction with [`get_recommendations`][connectwisdomservice_get_recommendations] and a `waitTimeSeconds` input for long-polling behavior and avoiding duplicate recommendations.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/notify_recommendations_received.html](https://paws-r.github.io/docs/connectwisdomservice/notify_recommendations_received.html) for full documentation.
#'
#' @param assistantId &#91;required&#93; The identifier of the Wisdom assistant. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#' @param recommendationIds &#91;required&#93; The identifiers of the recommendations.
#' @param sessionId &#91;required&#93; The identifier of the session. Can be either the ID or the ARN. URLs
#' cannot contain the ARN.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_notify_recommendations_received
connectwisdomservice_notify_recommendations_received <- function(assistantId, recommendationIds, sessionId) {
  op <- new_operation(
    name = "NotifyRecommendationsReceived",
    http_method = "POST",
    http_path = "/assistants/{assistantId}/sessions/{sessionId}/recommendations/notify",
    paginator = list()
  )
  input <- .connectwisdomservice$notify_recommendations_received_input(assistantId = assistantId, recommendationIds = recommendationIds, sessionId = sessionId)
  output <- .connectwisdomservice$notify_recommendations_received_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$notify_recommendations_received <- connectwisdomservice_notify_recommendations_received

#' Performs a manual search against the specified assistant
#'
#' @description
#' Performs a manual search against the specified assistant. To retrieve recommendations for an assistant, use [`get_recommendations`][connectwisdomservice_get_recommendations].
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/query_assistant.html](https://paws-r.github.io/docs/connectwisdomservice/query_assistant.html) for full documentation.
#'
#' @param assistantId &#91;required&#93; The identifier of the Wisdom assistant. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#' @param maxResults The maximum number of results to return per page.
#' @param nextToken The token for the next set of results. Use the value returned in the
#' previous response in the next request to retrieve the next set of
#' results.
#' @param queryText &#91;required&#93; The text to search for.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_query_assistant
connectwisdomservice_query_assistant <- function(assistantId, maxResults = NULL, nextToken = NULL, queryText) {
  op <- new_operation(
    name = "QueryAssistant",
    http_method = "POST",
    http_path = "/assistants/{assistantId}/query",
    paginator = list()
  )
  input <- .connectwisdomservice$query_assistant_input(assistantId = assistantId, maxResults = maxResults, nextToken = nextToken, queryText = queryText)
  output <- .connectwisdomservice$query_assistant_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$query_assistant <- connectwisdomservice_query_assistant

#' Removes a URI template from a knowledge base
#'
#' @description
#' Removes a URI template from a knowledge base.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/remove_knowledge_base_template_uri.html](https://paws-r.github.io/docs/connectwisdomservice/remove_knowledge_base_template_uri.html) for full documentation.
#'
#' @param knowledgeBaseId &#91;required&#93; The identifier of the knowledge base. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_remove_knowledge_base_template_uri
connectwisdomservice_remove_knowledge_base_template_uri <- function(knowledgeBaseId) {
  op <- new_operation(
    name = "RemoveKnowledgeBaseTemplateUri",
    http_method = "DELETE",
    http_path = "/knowledgeBases/{knowledgeBaseId}/templateUri",
    paginator = list()
  )
  input <- .connectwisdomservice$remove_knowledge_base_template_uri_input(knowledgeBaseId = knowledgeBaseId)
  output <- .connectwisdomservice$remove_knowledge_base_template_uri_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$remove_knowledge_base_template_uri <- connectwisdomservice_remove_knowledge_base_template_uri

#' Searches for content in a specified knowledge base
#'
#' @description
#' Searches for content in a specified knowledge base. Can be used to get a specific content resource by its name.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/search_content.html](https://paws-r.github.io/docs/connectwisdomservice/search_content.html) for full documentation.
#'
#' @param knowledgeBaseId &#91;required&#93; The identifier of the knowledge base. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#' @param maxResults The maximum number of results to return per page.
#' @param nextToken The token for the next set of results. Use the value returned in the
#' previous response in the next request to retrieve the next set of
#' results.
#' @param searchExpression &#91;required&#93; The search expression to filter results.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_search_content
connectwisdomservice_search_content <- function(knowledgeBaseId, maxResults = NULL, nextToken = NULL, searchExpression) {
  op <- new_operation(
    name = "SearchContent",
    http_method = "POST",
    http_path = "/knowledgeBases/{knowledgeBaseId}/search",
    paginator = list()
  )
  input <- .connectwisdomservice$search_content_input(knowledgeBaseId = knowledgeBaseId, maxResults = maxResults, nextToken = nextToken, searchExpression = searchExpression)
  output <- .connectwisdomservice$search_content_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$search_content <- connectwisdomservice_search_content

#' Searches for sessions
#'
#' @description
#' Searches for sessions.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/search_sessions.html](https://paws-r.github.io/docs/connectwisdomservice/search_sessions.html) for full documentation.
#'
#' @param assistantId &#91;required&#93; The identifier of the Wisdom assistant. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#' @param maxResults The maximum number of results to return per page.
#' @param nextToken The token for the next set of results. Use the value returned in the
#' previous response in the next request to retrieve the next set of
#' results.
#' @param searchExpression &#91;required&#93; The search expression to filter results.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_search_sessions
connectwisdomservice_search_sessions <- function(assistantId, maxResults = NULL, nextToken = NULL, searchExpression) {
  op <- new_operation(
    name = "SearchSessions",
    http_method = "POST",
    http_path = "/assistants/{assistantId}/searchSessions",
    paginator = list()
  )
  input <- .connectwisdomservice$search_sessions_input(assistantId = assistantId, maxResults = maxResults, nextToken = nextToken, searchExpression = searchExpression)
  output <- .connectwisdomservice$search_sessions_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$search_sessions <- connectwisdomservice_search_sessions

#' Get a URL to upload content to a knowledge base
#'
#' @description
#' Get a URL to upload content to a knowledge base. To upload content, first make a PUT request to the returned URL with your file, making sure to include the required headers. Then use [`create_content`][connectwisdomservice_create_content] to finalize the content creation process or [`update_content`][connectwisdomservice_update_content] to modify an existing resource. You can only upload content to a knowledge base of type CUSTOM.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/start_content_upload.html](https://paws-r.github.io/docs/connectwisdomservice/start_content_upload.html) for full documentation.
#'
#' @param contentType &#91;required&#93; The type of content to upload.
#' @param knowledgeBaseId &#91;required&#93; The identifier of the knowledge base. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_start_content_upload
connectwisdomservice_start_content_upload <- function(contentType, knowledgeBaseId) {
  op <- new_operation(
    name = "StartContentUpload",
    http_method = "POST",
    http_path = "/knowledgeBases/{knowledgeBaseId}/upload",
    paginator = list()
  )
  input <- .connectwisdomservice$start_content_upload_input(contentType = contentType, knowledgeBaseId = knowledgeBaseId)
  output <- .connectwisdomservice$start_content_upload_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$start_content_upload <- connectwisdomservice_start_content_upload

#' Adds the specified tags to the specified resource
#'
#' @description
#' Adds the specified tags to the specified resource.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/tag_resource.html](https://paws-r.github.io/docs/connectwisdomservice/tag_resource.html) for full documentation.
#'
#' @param resourceArn &#91;required&#93; The Amazon Resource Name (ARN) of the resource.
#' @param tags &#91;required&#93; The tags used to organize, track, or control access for this resource.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_tag_resource
connectwisdomservice_tag_resource <- function(resourceArn, tags) {
  op <- new_operation(
    name = "TagResource",
    http_method = "POST",
    http_path = "/tags/{resourceArn}",
    paginator = list()
  )
  input <- .connectwisdomservice$tag_resource_input(resourceArn = resourceArn, tags = tags)
  output <- .connectwisdomservice$tag_resource_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$tag_resource <- connectwisdomservice_tag_resource

#' Removes the specified tags from the specified resource
#'
#' @description
#' Removes the specified tags from the specified resource.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/untag_resource.html](https://paws-r.github.io/docs/connectwisdomservice/untag_resource.html) for full documentation.
#'
#' @param resourceArn &#91;required&#93; The Amazon Resource Name (ARN) of the resource.
#' @param tagKeys &#91;required&#93; The tag keys.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_untag_resource
connectwisdomservice_untag_resource <- function(resourceArn, tagKeys) {
  op <- new_operation(
    name = "UntagResource",
    http_method = "DELETE",
    http_path = "/tags/{resourceArn}",
    paginator = list()
  )
  input <- .connectwisdomservice$untag_resource_input(resourceArn = resourceArn, tagKeys = tagKeys)
  output <- .connectwisdomservice$untag_resource_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$untag_resource <- connectwisdomservice_untag_resource

#' Updates information about the content
#'
#' @description
#' Updates information about the content.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/update_content.html](https://paws-r.github.io/docs/connectwisdomservice/update_content.html) for full documentation.
#'
#' @param contentId &#91;required&#93; The identifier of the content. Can be either the ID or the ARN. URLs
#' cannot contain the ARN.
#' @param knowledgeBaseId &#91;required&#93; The identifier of the knowledge base. Can be either the ID or the ARN
#' @param metadata A key/value map to store attributes without affecting tagging or
#' recommendations. For example, when synchronizing data between an
#' external system and Wisdom, you can store an external version identifier
#' as metadata to utilize for determining drift.
#' @param overrideLinkOutUri The URI for the article. If the knowledge base has a templateUri,
#' setting this argument overrides it for this piece of content. To remove
#' an existing `overrideLinkOurUri`, exclude this argument and set
#' `removeOverrideLinkOutUri` to true.
#' @param removeOverrideLinkOutUri Unset the existing `overrideLinkOutUri` if it exists.
#' @param revisionId The `revisionId` of the content resource to update, taken from an
#' earlier call to [`get_content`][connectwisdomservice_get_content],
#' [`get_content_summary`][connectwisdomservice_get_content_summary],
#' [`search_content`][connectwisdomservice_search_content], or
#' [`list_contents`][connectwisdomservice_list_contents]. If included, this
#' argument acts as an optimistic lock to ensure content was not modified
#' since it was last read. If it has been modified, this API throws a
#' `PreconditionFailedException`.
#' @param title The title of the content.
#' @param uploadId A pointer to the uploaded asset. This value is returned by
#' [`start_content_upload`][connectwisdomservice_start_content_upload].
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_update_content
connectwisdomservice_update_content <- function(contentId, knowledgeBaseId, metadata = NULL, overrideLinkOutUri = NULL, removeOverrideLinkOutUri = NULL, revisionId = NULL, title = NULL, uploadId = NULL) {
  op <- new_operation(
    name = "UpdateContent",
    http_method = "POST",
    http_path = "/knowledgeBases/{knowledgeBaseId}/contents/{contentId}",
    paginator = list()
  )
  input <- .connectwisdomservice$update_content_input(contentId = contentId, knowledgeBaseId = knowledgeBaseId, metadata = metadata, overrideLinkOutUri = overrideLinkOutUri, removeOverrideLinkOutUri = removeOverrideLinkOutUri, revisionId = revisionId, title = title, uploadId = uploadId)
  output <- .connectwisdomservice$update_content_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$update_content <- connectwisdomservice_update_content

#' Updates the template URI of a knowledge base
#'
#' @description
#' Updates the template URI of a knowledge base. This is only supported for knowledge bases of type EXTERNAL. Include a single variable in `${variable}` format; this interpolated by Wisdom using ingested content. For example, if you ingest a Salesforce article, it has an `Id` value, and you can set the template URI to `https://myInstanceName.lightning.force.com/lightning/r/Knowledge__kav/*${Id}*/view`.
#'
#' See [https://paws-r.github.io/docs/connectwisdomservice/update_knowledge_base_template_uri.html](https://paws-r.github.io/docs/connectwisdomservice/update_knowledge_base_template_uri.html) for full documentation.
#'
#' @param knowledgeBaseId &#91;required&#93; The identifier of the knowledge base. Can be either the ID or the ARN.
#' URLs cannot contain the ARN.
#' @param templateUri &#91;required&#93; The template URI to update.
#'
#' @keywords internal
#'
#' @rdname connectwisdomservice_update_knowledge_base_template_uri
connectwisdomservice_update_knowledge_base_template_uri <- function(knowledgeBaseId, templateUri) {
  op <- new_operation(
    name = "UpdateKnowledgeBaseTemplateUri",
    http_method = "POST",
    http_path = "/knowledgeBases/{knowledgeBaseId}/templateUri",
    paginator = list()
  )
  input <- .connectwisdomservice$update_knowledge_base_template_uri_input(knowledgeBaseId = knowledgeBaseId, templateUri = templateUri)
  output <- .connectwisdomservice$update_knowledge_base_template_uri_output()
  config <- get_config()
  svc <- .connectwisdomservice$service(config)
  request <- new_request(svc, op, input, output)
  response <- send_request(request)
  return(response)
}
.connectwisdomservice$operations$update_knowledge_base_template_uri <- connectwisdomservice_update_knowledge_base_template_uri
